@@ -1,8 +1,9 @@
 from __future__ import annotations
-from macrokit import Expr, register_type, Head
+from macrokit import Expr, register_type, Head, symbol
 from enum import Enum
 from pathlib import Path
 import datetime
+from .widgets.sequence import ListDataView
 from .gui._base import MagicTemplate
 
 # classes
@@ -11,8 +12,9 @@ _date = Expr(Head.getattr, [datetime, datetime.date])
 _time = Expr(Head.getattr, [datetime, datetime.time])
 
 # magicgui-style input
-register_type(Enum, lambda e: repr(str(e.name)))
+register_type(Enum, lambda e: symbol(e.value))
 register_type(Path, lambda e: f"r'{e}'")
+register_type(ListDataView, lambda e: list(e))
 register_type(datetime.datetime, lambda e: Expr.parse_call(_datetime, (e.year, e.month, e.day, e.hour, e.minute), {}))
 register_type(datetime.date, lambda e: Expr.parse_call(_date, (e.year, e.month, e.day), {}))
 register_type(datetime.time, lambda e: Expr.parse_call(_time, (e.hour, e.minute), {}))
