@@ -13,7 +13,6 @@ from .gui.mgui_ext import AbstractAction, Action, WidgetAction
 
 if TYPE_CHECKING:
     from magicgui.widgets._protocols import WidgetProtocol
-    from magicgui.types import WidgetOptions
     from .gui._base import MagicTemplate
     _M = TypeVar("_M", bound=MagicTemplate)
 
@@ -35,11 +34,25 @@ class MagicField(Field, Generic[_W, _V]):
         self.guis: dict[int, _M] = {}
         self.name = name
         self.record = record
-        self.parent_class = None
+        
+        # MagicField has to remenber the first class that referred to itself so that it can
+        # "know" the namespace it belongs to.
+        self.parent_class: type = None
     
     def __repr__(self):
         return self.__class__.__name__.rstrip("Field") + super().__repr__()
     
+    
+    def copy(self) -> MagicField:
+        """Copy object."""
+        return self.__class__(
+            self.default,
+            self.default_factory,
+            self.metadata,
+            self.name,
+            self.record
+            )
+    
     def get_widget(self, obj: Any) -> _W:
         """
         Get a widget from ``obj``. This function will be called every time MagicField is referred
@@ -49,12 +62,11 @@ class MagicField(Field, Generic[_W, _V]):
         objtype = type(obj)
         if obj_id in self.guis.keys():
             widget = self.guis[obj_id]
-        elif self.parent_class is None or self.parent_class is objtype:    
+        else:
             widget = self.to_widget()
             self.guis[obj_id] = widget
-            self.parent_class = objtype
-        else:
-            raise TypeError(f"Cannot refer MagicField {self.name} from object of type {objtype}")
+            if self.parent_class is None:
+                self.parent_class = objtype
                 
         return widget
     
@@ -67,22 +79,32 @@ class MagicField(Field, Generic[_W, _V]):
         objtype = type(obj)
         if obj_id in self.guis.keys():
             action = self.guis[obj_id]
-        elif self.parent_class is None or self.parent_class is objtype:    
+        else:
             action = self.to_action()
             self.guis[obj_id] = action
-            self.parent_class = objtype
-        else:
-            raise TypeError(f"Cannot refer MagicField {self.name} from object of type {objtype}")
+            if self.parent_class is None:
+                self.parent_class = objtype
                 
         return action
     
     def as_getter(self, obj: Any) -> Callable[[Any], _V]:
-        """
-        Make a function that get the value of Widget or Action.
-        """        
+        """Make a function that get the value of Widget or Action."""        
         return lambda w: self.guis[id(obj)].value
     
+    # NOTE: Ideally these overload is needed for
+    # >>> @B.field.connect
+    # but in tern this will disable
+    # >>> self.B.field.value
+    # @overload
+    # def __get__(self, obj: Literal[None], objtype=None) -> MagicField[_W, _V]:
+    #     ...
+    
+    # @overload
+    # def __get__(self, obj: Any, objtype=None) -> _W:
+    #     ...
+    
     def __get__(self, obj: Any, objtype=None) -> _W:
+        """Get widget for the object."""
         if obj is None:
             return self
         return self.get_widget(obj)
@@ -149,13 +171,21 @@ class MagicField(Field, Generic[_W, _V]):
         return action
         
     def connect(self, func: Callable) -> Callable:
-        """
-        Set callback function to "ready to connect" state.
-        """        
+        """Set callback function to "ready to connect" state."""
         if not callable(func):
             raise TypeError("Cannot connect non-callable object")
         self.callbacks.append(func)
         return func
+    
+    def disconnect(self, func: Callable) -> None:
+        """
+        Disconnect callback from the field.
+        This method does NOT disconnect callbacks from widgets that are
+        already created.
+        """
+        i = self.callbacks.index(func)
+        self.callbacks.pop(i)
+        return None
 
     @property
     def value(self) -> Any:
@@ -209,24 +239,16 @@ class MagicValueField(MagicField, Generic[_W, _V]):
             raise AttributeError(f"Cannot set {self.__class__.__name__}.")
         self.get_widget(obj).value = value
 
+# magicgui symple types
 _X = TypeVar("_X", bound=Union[int, float, bool, str, Path, datetime.datetime, 
-                               datetime.date, datetime.time, Enum])
+                               datetime.date, datetime.time, Enum, range, slice])
 
 @overload
 def field(obj: _X, 
           *,
           name: str = "", 
           widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
-          record: bool = True) -> MagicField[ValueWidget, _X]:
-    ...
-
-@overload
-def field(obj: type[_X], 
-          *,
-          name: str = "", 
-          widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
+          options: dict[str, Any] = {},
           record: bool = True) -> MagicField[ValueWidget, _X]:
     ...
     
@@ -235,16 +257,25 @@ def field(obj: type[_W],
           *,
           name: str = "", 
           widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
+          options: dict[str, Any] = {},
           record: bool = True) -> MagicField[_W, Any]:
     ...
 
+@overload
+def field(obj: type[_X], 
+          *,
+          name: str = "", 
+          widget_type: str | type[WidgetProtocol] | None = None, 
+          options: dict[str, Any] = {},
+          record: bool = True) -> MagicField[ValueWidget, _X]:
+    ...
+
 @overload
 def field(obj: type[_M], 
           *,
           name: str = "", 
           widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
+          options: dict[str, Any] = {},
           record: bool = True) -> MagicField[_M, Any]:
     ...
     
@@ -253,7 +284,7 @@ def field(obj: Any,
           *,
           name: str = "", 
           widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
+          options: dict[str, Any] = {},
           record: bool = True) -> MagicField[Widget, Any]:
     ...
 
@@ -261,7 +292,7 @@ def field(obj: Any = MISSING,
           *, 
           name: str = "", 
           widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
+          options: dict[str, Any] = {},
           record: bool = True
           ) -> MagicField[Widget, Any]:
     """
@@ -296,7 +327,7 @@ def vfield(obj: type[_V],
           *,
           name: str = "", 
           widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
+          options: dict[str, Any] = {},
           record: bool = True) -> MagicValueField[Widget, _V]:
     ...
     
@@ -305,7 +336,7 @@ def vfield(obj: _V,
           *,
           name: str = "", 
           widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
+          options: dict[str, Any] = {},
           record: bool = True) -> MagicValueField[Widget, _V]:
     ...
 
@@ -314,7 +345,7 @@ def vfield(obj: Any,
           *,
           name: str = "", 
           widget_type: str | type[WidgetProtocol] | None = None, 
-          options: WidgetOptions = {},
+          options: dict[str, Any] = {},
           record: bool = True) -> MagicValueField[Widget, Any]:
     ...
     
@@ -322,7 +353,7 @@ def vfield(obj: Any = MISSING,
            *, 
            name: str = "", 
            widget_type: str | type[WidgetProtocol] | None = None, 
-           options: WidgetOptions = {},
+           options: dict[str, Any] = {},
            record: bool = True,
            ) -> MagicValueField[Widget, Any]:
     """
@@ -359,7 +390,7 @@ def vfield(obj: Any = MISSING,
 def _get_field(obj, 
                name: str, 
                widget_type: str | type[WidgetProtocol] | None, 
-               options: WidgetOptions,
+               options: dict[str, Any],
                record: bool,
                field_class: type[MagicField]
                ) -> type[MagicField]:
