@@ -4,7 +4,6 @@ from typing import (
     Any,
     Callable,
     TYPE_CHECKING,
-    Generic,
     Iterable,
     Iterator,
     TypeVar,
@@ -17,6 +16,7 @@ import warnings
 import os
 from enum import Enum
 import warnings
+import weakref
 from docstring_parser import parse, compose
 from qtpy.QtWidgets import QWidget, QDockWidget
 from qtpy.QtGui import QIcon
@@ -31,7 +31,8 @@ from magicgui.widgets import (
     Container,
     Image,
     Table,
-    Label
+    Label,
+    MainWindow,
     )
 from magicgui.application import use_app
 from magicgui.widgets._bases.widget import Widget
@@ -71,6 +72,7 @@ class PopUpMode(Enum):
 class ErrorMode(Enum):
     msgbox = "msgbox"
     stderr = "stderr"
+    stdout = "stdout"
     
 defaults = {"popup_mode": PopUpMode.popup,
             "error_mode": ErrorMode.msgbox,
@@ -79,11 +81,11 @@ defaults = {"popup_mode": PopUpMode.popup,
 
 _RESERVED = {"__magicclass_parent__", "__magicclass_children__", "_close_on_run", 
              "_error_mode", "_popup_mode", "_my_symbol", "_macro_instance", "macro",
-             "annotation", "enabled", "gui_only", "height", "label_changed", "label",
-             "layout", "labels", "margins", "max_height", "max_width", "min_height", 
-             "min_width", "name", "options", "param_kind", "parent_changed", 
-             "tooltip", "visible", "widget_type", "width", "wraps", "_unwrap_method",
-             "_search_parent_magicclass", "_iter_child_magicclasses", 
+             "annotation", "enabled", "find_ancestor", "gui_only", "height", 
+             "label_changed", "label", "layout", "labels", "margins", "max_height",
+             "max_width", "min_height", "min_width", "name", "options", "param_kind",
+             "parent_changed", "tooltip", "visible", "widget_type", "width", "wraps",
+             "_unwrap_method", "_search_parent_magicclass", "_iter_child_magicclasses", 
              }
 
 def check_override(cls: type):
@@ -107,7 +109,8 @@ def check_override(cls: type):
         raise AttributeError(
             f"Cannot override magic class reserved attributes: {collision}"
             )
-          
+      
+_T = TypeVar("_T")    
 
 class MagicTemplate: 
     __doc__ = ""
@@ -203,7 +206,7 @@ class MagicTemplate:
         Return napari.Viewer if magic class is a dock widget of a viewer.
         """
         parent_self = self._search_parent_magicclass()
-        if parent_self.parent is None:
+        if parent_self.native.parent() is None:
             return None
         try:
             from napari.utils._magicgui import find_viewer_ancestor
@@ -227,13 +230,54 @@ class MagicTemplate:
             dock = None
             
         return dock
-
     
+
+    def find_ancestor(self, ancestor: type[_T]) -> _T:
+        """
+        Find magic class ancestor whose type matches the input.
+        This method is useful when a child widget class is defined outside a magic
+        class while it needs access to its parent.
+
+        Parameters
+        ----------
+        ancestor : type of MagicTemplate
+            Type of ancestor to search for.
+
+        Returns
+        -------
+        MagicTemplate
+            Magic class object if found.
+        """        
+        if not isinstance(ancestor, type):
+            raise TypeError(
+                "The first argument of 'find_ancestor' must be a type but got "
+                f"{type(ancestor)}"
+                )
+
+        current_self = self
+        while type(current_self) is not ancestor:
+            current_self = current_self.__magicclass_parent__
+            if current_self is None:
+                raise RuntimeError(
+                    f"Magic class {ancestor.__name__} not found. {ancestor.__name__} it "
+                    f"is not an ancestor of {self.__class__.__name__}"
+                    )
+        return current_self
+
+
     def objectName(self) -> str:
         """
+        Return object name of the QWidget.
+        
         This function makes the object name discoverable by napari's 
-        `viewer.window.add_dock_widget` function.
-        """        
+        `viewer.window.add_dock_widget` function. At the same time, since this function
+        will always be called when the widget is added as a dock widget of napari, we
+        can import macro recorders for napari types in the appropriate timing.
+        """
+        try:
+            from . import _napari_type  # load default macro recorder.
+        except Exception:
+            pass
         return self.native.objectName()
 
     @classmethod
@@ -243,10 +287,10 @@ class MagicTemplate:
               template: Callable | None = None,
               copy: bool = False) -> Callable:
         """
-        Wrap a parent method in a child magic-class. Wrapped method will appear in 
-        the child widget but behaves as if it is in the parent widget.
+        Wrap a parent method in a child magic-class. 
         
-        Basically, this function is used as a wrapper like below.
+        Wrapped method will appear in the child widget but behaves as if it is in
+        the parent widget. Basically, this function is used as a wrapper like below.
         
         .. code-block:: python
         
@@ -421,6 +465,8 @@ class MagicTemplate:
             wrapper = _raise_error_in_msgbox
         elif self._error_mode == ErrorMode.stderr:
             wrapper = _identity_wrapper
+        elif self._error_mode == ErrorMode.stdout:
+            wrapper = _print_error
         else:
             raise ValueError(self._error_mode)
         
@@ -492,7 +538,7 @@ class MagicTemplate:
             def run_function():
                 # NOTE: callback must be defined inside function. Magic class must be
                 # "compiled" otherwise function wrappings are not ready!
-                mgui = _build_mgui(widget, func)
+                mgui = _build_mgui(widget, func, self)
                 mgui.native.setParent(self.native, mgui.native.windowFlags())
                 if (mgui.call_count == 0 and 
                     len(mgui.called._slots) == 0 and 
@@ -507,7 +553,7 @@ class MagicTemplate:
         elif nparams == 1 and isinstance(fgui[0], FileEdit):
             # We don't want to open a magicgui dialog and again open a file dialog.
             def run_function():
-                mgui = _build_mgui(widget, func)
+                mgui = _build_mgui(widget, func, self)
                 mgui.native.setParent(self.native, mgui.native.windowFlags())
                 if (mgui.call_count == 0 and 
                     len(mgui.called._slots) == 0 and 
@@ -532,7 +578,7 @@ class MagicTemplate:
             
         else:                
             def run_function():
-                mgui = _build_mgui(widget, func)
+                mgui = _build_mgui(widget, func, self)
                 if mgui.call_count == 0 and len(mgui.called._slots) == 0:
                     
                     # deal with popup mode.
@@ -567,10 +613,13 @@ class MagicTemplate:
                             child_self.insert(i+1, mgui)
                             
                     elif self._popup_mode == PopUpMode.dock:
+                        from .class_gui import MainWindowClassGui
                         parent_self = self._search_parent_magicclass()
                         viewer = parent_self.parent_viewer
                         if viewer is None:
-                            if not hasattr(parent_self.native, "addDockWidget"):
+                            if isinstance(parent_self, MainWindowClassGui):
+                                parent_self.add_dock_widget(mgui)
+                            else:
                                 msg = (
                                     "Cannot add dock widget to a normal container. Please use\n"
                                     ">>> @magicclass(widget_type='mainwindow')\n"
@@ -578,16 +627,8 @@ class MagicTemplate:
                                     "widget in napari.")
                                 warnings.warn(msg, UserWarning)
                             
-                            else:
-                                from qtpy.QtWidgets import QDockWidget
-                                from qtpy.QtCore import Qt
-                                dock = QDockWidget(_get_widget_name(widget), self.native)
-                                dock.setWidget(mgui.native)
-                                parent_self.native.addDockWidget(
-                                    Qt.DockWidgetArea.RightDockWidgetArea, dock
-                                    )
                         else:
-                            dock = viewer.window.add_dock_widget(
+                            viewer.window.add_dock_widget(
                                 mgui, name=_get_widget_name(widget), area="right"
                                 )
                     else:
@@ -637,8 +678,10 @@ class MagicTemplate:
     def _search_parent_magicclass(self) -> MagicTemplate:
         """Find the ancestor."""
         current_self = self
-        while getattr(current_self, "__magicclass_parent__", None) is not None:
-            current_self = current_self.__magicclass_parent__
+        while (
+            parent := getattr(current_self, "__magicclass_parent__", None)
+            ) is not None:
+            current_self = parent
         return current_self
 
 
@@ -706,18 +749,18 @@ class ContainerLikeGui(BaseGui, mguiLike, MutableSequence):
         fld.name = fld.name or name.replace("_", " ")
         action = fld.get_action(self)
             
-        if action.support_value:
-            # If the field has callbacks, connect it to the newly generated widget.
-            for callback in fld.callbacks:
-                # funcname = callback.__name__
-                action.changed.connect(define_callback(self, callback))
-                     
+        if action.support_value:     
             # By default, set value function will be connected to the widget.
             if fld.record:
                 getvalue = type(fld) is MagicField
                 f = value_widget_callback(self, action, name, getvalue=getvalue)
                 action.changed.connect(f)
                 
+            # If the field has callbacks, connect it to the newly generated widget.
+            for callback in fld.callbacks:
+                # funcname = callback.__name__
+                action.changed.connect(define_callback(self, callback))
+                
         return action
     
     
@@ -813,9 +856,12 @@ def _temporal_function_gui_callback(bgui: MagicTemplate,
         raise TypeError("fgui must be FunctionGui object.")
         
     return_type = fgui.return_annotation
-    result_required = return_type is not inspect._empty
+    result_required = return_type is not inspect.Parameter.empty
     
-    def _after_run():
+    def _after_run(e: Exception = None):
+        if isinstance(e, Exception):
+            # If function call ended with an exception, don't record macro.
+            return
         bound = fgui._previous_bound
         result = Symbol("result")
         # Standard button will be connected with two callbacks.
@@ -860,7 +906,8 @@ def _temporal_function_gui_callback(bgui: MagicTemplate,
     
     return _after_run
 
-def _build_mgui(widget_, func):
+
+def _build_mgui(widget_: Action | PushButtonPlus, func: Callable, parent: BaseGui):
     if widget_.mgui is not None:
         return widget_.mgui
     try:
@@ -884,6 +931,7 @@ def _build_mgui(widget_, func):
     widget_.mgui = mgui
     name = widget_.name or ""
     mgui.native.setWindowTitle(name.replace("_", " "))
+    mgui._magicclass_parent_ref = weakref.ref(parent)
     return mgui
         
 _C = TypeVar("_C", Callable, type)
@@ -929,7 +977,7 @@ def wraps(template: Callable | inspect.Signature) -> Callable[[_C], _C]:
         new_params: list[Param] = []
         
         for k, v in old_params.items():
-            if v.annotation is inspect._empty and v.default is inspect._empty:
+            if v.annotation is Param.empty and v.default is Param.empty:
                 new_params.append(
                     template_params.get(k, 
                                         Param(k, Param.POSITIONAL_OR_KEYWORD)
@@ -959,37 +1007,46 @@ def wraps(template: Callable | inspect.Signature) -> Callable[[_C], _C]:
         return f
     return wrapper
 
+
 def _raise_error_in_msgbox(_func: Callable, parent: Widget = None):
-    """
-    If exception happened inside function, then open a message box.
-    """    
+    """If exception happened inside function, then open a message box."""
     def wrapped_func(*args, **kwargs):
-        from qtpy.QtWidgets import QMessageBox
         try:
             out = _func(*args, **kwargs)
         except Exception as e:
-            QMessageBox.critical(
-                parent.native, e.__class__.__name__, str(e), QMessageBox.Ok
-                )
+            from ._message_box import QtErrorMessageBox
+            QtErrorMessageBox.raise_(e, parent=parent.native)
             out = e
         return out
     
     return wrapped_func
 
+
+def _print_error(_func: Callable, parent: Widget = None):
+    """If exception happened inside function, then print it."""
+    def wrapped_func(*args, **kwargs):
+        try:
+            out = _func(*args, **kwargs)
+        except Exception as e:
+            print(f"{e.__class__.__name__}: {e}")
+            out = e
+        return out
+    
+    return wrapped_func
+
+
 def _identity_wrapper(_func: Callable, parent: Widget = None):
-    """
-    Do nothing.
-    """    
+    """Do nothing."""    
     def wrapped_func(*args, **kwargs):
         return _func(*args, **kwargs)
     return wrapped_func
 
+
 def _n_parameters(func: Callable):
-    """
-    Count the number of parameters of a callable object.
-    """    
+    """Count the number of parameters of a callable object."""    
     return len(inspect.signature(func).parameters)
 
+
 def _get_index(container: Container, widget_or_name: Widget | str) -> int:
     """
     Identical to container[widget_or_name], which sometimes doesn't work
@@ -1006,6 +1063,7 @@ def _get_index(container: Container, widget_or_name: Widget | str) -> int:
         raise ValueError(f"{widget_or_name} not found in {container}")
     return i
 
+
 def _child_that_has_widget(self: BaseGui, method: Callable, 
                            widget_or_name: Widget | str) -> BaseGui:
     child_clsname = get_additional_option(method, "into")
@@ -1039,8 +1097,10 @@ def _method_as_getter(self, bound_value: Callable):
         return getattr(ins, funcname)(w)
     return _func
 
-def _field_as_getter(self, bound_value: MagicField):
+def _field_as_getter(self: BaseGui, bound_value: MagicField):
+    """Called when a MagicField is used in Bound method."""
     def _func(w):
+        # First we have to know where (which instance) MagicField came from.
         namespace = bound_value.parent_class.__qualname__
         clsnames = namespace.split(".")
         ins = self
@@ -1054,7 +1114,8 @@ def _field_as_getter(self, bound_value: MagicField):
         i = clsnames.index(type(ins).__name__)
         for clsname in clsnames[i:]:
             ins = getattr(ins, clsname, ins)
-            
+        
+        # Extract correct widget from MagicField
         _field_widget = bound_value.get_widget(ins)
         if not hasattr(_field_widget, "value"):
             raise TypeError(
@@ -1073,9 +1134,7 @@ def value_widget_callback(gui: MagicTemplate,
                           widget: ValueWidget, 
                           name: str, 
                           getvalue: bool = True):
-    """
-    Define a ValueWidget callback, including macro recording.
-    """    
+    """Define a ValueWidget callback, including macro recording."""
     sym_name = Symbol(name)
     sym_value = Symbol("value")
     def _set_value():
