@@ -1,12 +1,12 @@
 from __future__ import annotations
 from inspect import signature
-from typing import Any, Callable, TypeVar
+from typing import Any, Callable, Sequence, TypeVar
 import warnings
 from qtpy.QtWidgets import QMenuBar, QWidget, QMainWindow, QBoxLayout
 from qtpy.QtCore import Qt
 from magicgui.widgets import Container, MainWindow,Label, FunctionGui, Image, Table
 from magicgui.widgets._bases import Widget, ButtonWidget, ValueWidget, ContainerWidget
-from magicgui.widgets._concrete import _LabeledWidget
+from magicgui.widgets._concrete import _LabeledWidget, ContainerWidget
 from macrokit import Symbol
 
 from .mgui_ext import PushButtonPlus
@@ -35,6 +35,7 @@ from ..utils import iter_members, extract_tooltip
 from ..fields import MagicField
 from ..signature import get_additional_option
 from .._app import run_app
+from ._dock_widget import QtDockWidget
 
 # For Containers that belong to these classes, menubar must be set to _qwidget.layout().
 _USE_OUTER_LAYOUT = (ScrollableContainer, DraggableContainer, SplitterContainer, TabbedContainer)
@@ -58,22 +59,22 @@ class ClassGuiBase(BaseGui):
         fld.name = fld.name or name.replace("_", " ")
         widget = fld.get_widget(self)
             
-        if isinstance(widget, (ValueWidget, Container)):
+        if isinstance(widget, (ValueWidget, ContainerWidget)):
             # If the field has callbacks, connect it to the newly generated widget.
-            for callback in fld.callbacks:
-                # funcname = callback.__name__
-                widget.changed.connect(define_callback(self, callback))
-                
-            if hasattr(widget, "value") and fld.record:
+            if (isinstance(widget, ValueWidget) or hasattr(widget, "value")) and fld.record:
                 # By default, set value function will be connected to the widget.
                 getvalue = type(fld) is MagicField
                 f = value_widget_callback(self, widget, name, getvalue=getvalue)
                 widget.changed.connect(f)
+                
+            for callback in fld.callbacks:
+                # funcname = callback.__name__
+                widget.changed.connect(define_callback(self, callback))
         
         elif fld.callbacks:
             warnings.warn(
                 f"{type(widget).__name__} does not have value-change callback. "
-                f"Connecting callback functions does no effect.",
+                "Connecting callback functions does no effect.",
                 UserWarning
                 )
                 
@@ -96,9 +97,10 @@ class ClassGuiBase(BaseGui):
         base_members |= set(x[0] for x in iter_members(ClassGuiBase))
         
         _hist: list[tuple[str, str, str]] = [] # for traceback
+        _annot = ClassGuiBase.__annotations__.keys()
         
         for name, attr in filter(lambda x: x[0] not in base_members, iter_members(cls)):
-            if name in ClassGuiBase.__annotations__.keys() or isinstance(attr, property):
+            if name in _annot or isinstance(attr, (property, classmethod, staticmethod)):
                 continue
             
             try:
@@ -190,6 +192,8 @@ class ClassGuiBase(BaseGui):
                         # NOTE: Here any custom callable objects could be given. Some callable
                         # objects can be incompatible (like "Signal" object in magicgui) but
                         # useful. Those callable objects should be passed from widget construction.
+                        if name.startswith("_") or not get_additional_option(attr, "gui", True):
+                            continue
                         try:
                             widget = self._create_widget_from_method(widget)
                         except AttributeError:
@@ -292,13 +296,17 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
         def _fast_insert(self: cls, key: int, widget: Widget | Callable):
             if isinstance(widget, Callable):
                 # Sometimes uses want to dynamically add new functions to GUI.
+                method_name = getattr(widget, "__name__", None)
+                if method_name and not hasattr(self, method_name):
+                    object.__setattr__(self, method_name, widget)
+                    
                 if isinstance(widget, FunctionGui):
                     if widget.parent is None:
                         f = nested_function_gui_callback(self, widget)
                         widget.called.connect(f)
                 else:
                     widget = self._create_widget_from_method(widget)
-                
+
             # _hide_labels should not contain Container because some ValueWidget like widgets
             # are Containers.
             _hide_labels = (_LabeledWidget, ButtonWidget, ClassGuiBase, FreeWidget, Label,
@@ -309,9 +317,14 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
             
             if hasattr(widget, "__magicclass_parent__") or \
                 hasattr(widget.__class__, "__magicclass_parent__"):
-                if isinstance(widget, ClassGuiBase) and self._remove_child_margins:
-                    widget.margins = (0, 0, 0, 0)
                 widget.__magicclass_parent__ = self
+                if isinstance(widget, ClassGuiBase):
+                    if self._remove_child_margins:
+                        widget.margins = (0, 0, 0, 0)
+                    self.__magicclass_children__.append(widget)
+                    widget._my_symbol = Symbol(widget.name)
+                    # NOTE: This is not safe. Attributes could collision and macro recording
+                    # may break if not correctly named.
                 
             _widget = widget
 
@@ -389,6 +402,74 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
 
             return None
         
+        if issubclass(container, MainWindow):
+            # Similar to napari's viewer.window.add_dock_widget.
+            # See napari/_qt/widgets/qt_viewer_dock_widget.py
+            from ..wrappers import nogui
+            
+            # This function will be detected as non-reserved method so that magicclass will
+            # try to convert it into widget. Should decorate with @nogui.
+            @nogui
+            def add_dock_widget(self: MainWindowClassGui | BaseGui, 
+                                widget: Widget,
+                                *, 
+                                name: str = "", 
+                                area: str = "right", 
+                                allowed_areas: Sequence[str] | None = None):
+                """
+                Add a widget as a dock widget of the main window.
+                This method follows napari's "add_dock_widget" method.
+
+                Parameters
+                ----------
+                widget : Widget
+                    Widget that will be converted into a dock widget and added to the main
+                    window.
+                name : str, optional
+                    Name of the dock widget.
+                area : str, default is "right"
+                    Initial dock widget area.
+                allowed_areas : sequence of str, optional
+                    Allowed dock widget area. Allow all areas by default.
+                """
+                name = name or widget.name
+                mainwin: QMainWindow = self.native
+                dock = QtDockWidget(mainwin, 
+                                    widget.native,
+                                    name=name.replace("_", " "),
+                                    area=area,
+                                    allowed_areas=allowed_areas
+                                    )
+
+                mainwin.addDockWidget(QtDockWidget.areas[area], dock)
+                if isinstance(widget, BaseGui):
+                    widget.__magicclass_parent__ = self
+                    self.__magicclass_children__.append(widget)
+                    widget._my_symbol = Symbol(name)
+            
+            @nogui
+            def remove_dock_widget(self: cls, widget: Widget):
+                dock = None
+                i_dock = -1
+                for i, child in enumerate(self.__magicclass_children__):
+                    if child is widget:
+                        dock = child.native.parent()
+                        if not isinstance(dock, QtDockWidget):
+                            dock = None
+                        i_dock = i
+                        self.__magicclass_parent__ = None
+                        break
+                else:
+                    raise RuntimeError("Dock widget not found.")
+                
+                mainwin: QMainWindow = self.native
+                mainwin.removeDockWidget(dock)
+                self.__magicclass_children__.pop(i_dock)
+                
+
+            cls.add_dock_widget = add_dock_widget
+            cls.remove_dock_widget = remove_dock_widget
+        
         cls.__init__ = __init__
         cls.__setattr__ = __setattr__
         cls._fast_insert = _fast_insert
