@@ -64,6 +64,9 @@ class MenuGuiBase(ContainerLikeGui):
         _hist: list[tuple[str, str, str]] = [] # for traceback
         
         for name, attr in filter(lambda x: x[0] not in base_members, iter_members(cls)):
+            if isinstance(attr, property):
+                continue
+            
             try:
                 if isinstance(attr, type):
                     if not issubclass(attr, BaseGui):
@@ -98,6 +101,10 @@ class MenuGuiBase(ContainerLikeGui):
                         widget = WidgetAction(widget)
                         
                 elif isinstance(widget, Widget):
+                    if not widget.name:
+                        widget.name = name
+                    if hasattr(widget, "text") and not widget.text:
+                        widget.text = widget.name.replace("_", " ")
                     widget = WidgetAction(widget)
 
                 if isinstance(widget, (MenuGuiBase, AbstractAction, Callable, Widget)):
@@ -142,6 +149,10 @@ class MenuGuiBase(ContainerLikeGui):
     def _fast_insert(self, key: int, obj: Callable | MenuGuiBase | AbstractAction) -> None:
         if isinstance(obj, Callable):
             # Sometimes uses want to dynamically add new functions to GUI.
+            method_name = getattr(obj, "__name__", None)
+            if method_name and not hasattr(self, method_name):
+                object.__setattr__(self, method_name, obj)
+                
             if isinstance(obj, FunctionGui):
                 if obj.parent is None:
                     f = nested_function_gui_callback(self, obj)
