@@ -108,6 +108,9 @@ class ToolBarGui(ContainerLikeGui):
         _hist: list[tuple[str, str, str]] = [] # for traceback
         
         for name, attr in filter(lambda x: x[0] not in base_members, iter_members(cls)):
+            if isinstance(attr, property):
+                continue
+            
             try:
                 if isinstance(attr, type):
                     if not issubclass(attr, BaseGui):
@@ -203,8 +206,8 @@ class ToolBarGui(ContainerLikeGui):
         
         self._unify_label_widths()
         return None
-    
-    
+
+
     def _fast_insert(self, key: int, obj: AbstractAction | Callable) -> None:
         """
         Insert object into the toolbar. Could be widget or callable.
@@ -218,6 +221,10 @@ class ToolBarGui(ContainerLikeGui):
         """
         if isinstance(obj, Callable):
             # Sometimes uses want to dynamically add new functions to GUI.
+            method_name = getattr(obj, "__name__", None)
+            if method_name and not hasattr(self, method_name):
+                object.__setattr__(self, method_name, obj)
+                
             if isinstance(obj, FunctionGui):
                 if obj.parent is None:
                     f = nested_function_gui_callback(self, obj)
