@@ -11,6 +11,10 @@ class AdditionalOptions(TypedDict):
     record: bool
     keybinding: str
     into: str
+    copyto: str
+    moveto: str
+    gui: bool
+
 
 def upgrade_signature(func, 
                       gui_options: dict = None, 
@@ -72,7 +76,7 @@ def get_additional_option(obj: Any, option: str, default: Any = None):
         return opt.get(option, default)
     else:
         return default
-    
+
 
 class _void:
     """private sentinel."""
@@ -145,4 +149,4 @@ class MagicMethodSignature(MagicSignature):
                    return_annotation=return_annotation,
                    gui_options = cls.get_gui_options(self),
                    caller_options = self.caller_options,
-                   additional_options = self.additional_options)
\ No newline at end of file
+                   additional_options = self.additional_options)
