@@ -10,15 +10,15 @@ from ..widgets import ListEdit
 
 @type_matcher
 def list_of_any(value, annotation) -> WidgetTuple | None:
-    """Determine if value/annotation is list[...]."""
-    if annotation and annotation is not inspect._empty:
+    """Determine if value/annotation is a list[X]."""
+    if annotation and annotation is not inspect.Parameter.empty:
         orig = get_origin(annotation)
         args = get_args(annotation)
         if not (inspect.isclass(orig) and args):
             return None
         if is_subclass(orig, list) or isinstance(orig, list):
-            return ListEdit, {"annotation": args[0]}
+            return ListEdit, {}
     elif value:
-        if isinstance(value, list) and len(set(type(v) for v in value)) == 1:
-            return ListEdit, {"value": value}
-    return None
\ No newline at end of file
+        if isinstance(value, list) and len({type(v) for v in value}) == 1:
+            return ListEdit, {}
+    return None
