@@ -10,15 +10,15 @@ from ..widgets import TupleEdit
 
 @type_matcher
 def tuple_of_any(value, annotation) -> WidgetTuple | None:
-    """Determine if value/annotation is tuple[...]."""
-    if annotation and annotation is not inspect._empty:
+    """Determine if value/annotation is a tuple[X, Y, ...]."""
+    if annotation and annotation is not inspect.Parameter.empty:
         orig = get_origin(annotation)
         args = get_args(annotation)
         if not (inspect.isclass(orig) and args):
             return None
         if is_subclass(orig, tuple) or isinstance(orig, tuple):
-            return TupleEdit, {"annotation": annotation}
+            return TupleEdit, {}
     elif value:
         if isinstance(value, tuple):
-            return TupleEdit, {"value": value}
-    return None
\ No newline at end of file
+            return TupleEdit, {}
+    return None
