@@ -8,6 +8,7 @@ from qtpy.QtWidgets import QApplication, QMessageBox
 __all__ = ["MessageBoxMode", "show_messagebox", "open_url", "screen_center", "to_clipboard",
            "iter_members", "extract_tooltip", "get_signature"]
 
+
 def iter_members(cls: type, exclude_prefix: str = "__") -> list[str, Any]:
     """
     Iterate over all the members in the order of source code line number. 
@@ -18,7 +19,7 @@ def iter_members(cls: type, exclude_prefix: str = "__") -> list[str, Any]:
     processed = set()
     names: list[str] = list(cls.__dict__.keys())
     try:
-        for base in mro:
+        for base in reversed(mro):
             for k in base.__dict__.keys():
                 if k not in names:
                     names.append(k)
@@ -42,9 +43,10 @@ def iter_members(cls: type, exclude_prefix: str = "__") -> list[str, Any]:
         if not key.startswith(exclude_prefix):
             yield key, value
         processed.add(key)
-    
 
-def extract_tooltip(obj: Any) -> str:    
+
+def extract_tooltip(obj: Any) -> str:
+    """Extract docstring for tooltip."""
     doc = parse(obj.__doc__)
     if doc.short_description is None:
         return ""
