@@ -21,7 +21,8 @@ from .containers import (
     ToolBoxContainer
     )
 from .pywidgets import ListWidget, DictWidget
-from .misc import Figure, ConsoleTextEdit, CheckButton
+from .color import ColorEdit, ColorSlider
+from .misc import Figure, ConsoleTextEdit, CheckButton, SpreadSheet
 from .separator import Separator
 from .sequence import ListEdit, TupleEdit
 from .utils import FreeWidget
@@ -29,6 +30,8 @@ from .utils import FreeWidget
 
 __all__ = ["ListWidget", 
            "Figure",
+           "ColorEdit",
+           "ColorSlider",
            "ConsoleTextEdit",
            "CheckButton",
            "Separator",
@@ -46,6 +49,7 @@ __all__ = ["ListWidget",
            "CollapsibleContainer",
            "HCollapsibleContainer",
            "SplitterContainer",
+           "SpreadSheet",
            "StackedContainer",
            "TabbedContainer",
            "ToolBoxContainer",
