@@ -1,4 +1,6 @@
-from magicclass import magicclass, set_options, set_design, do_not_record, confirm
+from types import MethodType
+from magicclass import magicclass, set_options, set_design, do_not_record, confirm, nogui
+from magicgui.widgets import PushButton
 
 def test_set_options():
     @magicclass
@@ -51,12 +53,41 @@ def test_do_not_record():
 def test_confirm():
     @magicclass
     class A:
+        @magicclass
+        class B:
+            def g(self): ...
+            
         @confirm("really?")
         def f(self):
             self.a = 0
+        
+        @B.wraps
+        @confirm("really?")
+        def g(self):
+            self.a = 0
     
     ui = A()
     ui["f"].changed()
     assert ui["f"].mgui[0].value == "really?"
     ui["f"].mgui[-1].changed()
-    assert str(ui.macro[-1]) == "ui.f()"
\ No newline at end of file
+    assert str(ui.macro[-1]) == "ui.f()"
+    
+    
+    ui.B["g"].changed()
+    assert ui["g"].mgui[0].value == "really?"
+    ui["g"].mgui[-1].changed()
+    assert str(ui.macro[-1]) == "ui.g()"
+
+def test_nogui():
+    @magicclass
+    class A:
+        @nogui
+        def f(self):
+            pass
+        
+        def g(self):
+            pass
+    
+    ui = A()
+    assert isinstance(ui["f"], MethodType)
+    assert isinstance(ui["g"], PushButton)
\ No newline at end of file
